@@ -20,6 +20,8 @@
  */
 
 enum sim_fileid {
+	SIM_EFPL_FILEID = 0x2f05,
+	SIM_EFLI_FILEID = 0x6f05,
 	SIM_EFMSISDN_FILEID = 0x6f40,
 	SIM_EFSPN_FILEID = 0x6f46,
 	SIM_EFSDN_FILEID = 0x6f49,
@@ -31,6 +33,9 @@ enum sim_fileid {
 	SIM_EFMWIS_FILEID = 0x6fca,
 	SIM_EFSPDI_FILEID = 0x6fcd,
 	SIM_EFECC_FILEID = 0x6fb7,
+	SIM_EFCBMIR_FILEID = 0x6f50,
+	SIM_EFCBMI_FILEID = 0x6f45,
+	SIM_EFCBMID_FILEID = 0x6f48,
 };
 
 /* 51.011 Section 9.3 */
